/* --- rtb/adecomm/_chosobj.p --- */
/* --- Roundtable intercept of Choose SmartObject Dialog. --- */

/* -----------------------------------------------------------------------
  Program Description:
    - When Roundtable is active, this routine will be in the PROPATH before
      Progress's standard _chosobj.w, and therefore will be run instead of
      the Progress _chosobj.w.

    - Publish the "evRtbAdeGetFile" event
    - "evRtbAdeGetFile" event allows the user to do one of the
      following:
          1) Select a SmartObject from Roundtable.
          2) Cancel the Choose SmartObject operation.
          3) Select a SmartObject object not managed by Rountable.
    - The users choice is returned to this procedure via variable
      Mrtb-action.
    - The users action is performed.  Depending on users choice:
          1) SmartObject selected is returned to routine calling this.
          2) Cancel is returned to rountine calling this.
          3) Progress _chosobj.w is run.


  Program Variable Descriptions:
    - Input Parameters (Progress Parameter Discription):
        Pmode (char) - defines mode for dialog: {&WT-CONTROL} OR ""
                       (i.e. VBX or non-VBX (SmartObjects)
        Pcst-attr (char) - chr(10) delimited list of options from .cst file:
                      DIRECTORY-LIST dir1,dir2,...       /* list of dirs to search */
                      FILTERS        filter1,filter2,... /* file filters to use */
                      TITLE          <string>            /* title for this dialog */
        PnewTemplate (char) - template designated for a new object of this type
                              (e.g. from .cst file: NEW-TEMPLATE <templ-name>)
        PshowOptions (char) - buttons to enable in the dialog-box in a CDL:
                              BROWSE, NEW, PREVIEW
    - Output Parameters (Progress Parameter Discription):
        Pfilechosen (char) - filename of object to draw in a window or dialog
        PotherThing (char) - VBX chosen to draw (unused for SmartObjects)
        Pcancelled  (log)  - True if the user cancelled out of the dialog

    - Local Varaibles:
        Mgetfile    - Fully quantified path to Progress _chosobj.p.
        Mrtb-action - user action to be perform (returned from evRtbAdeGetFile).

------------------------------------------------------------------------ */

/* --- Define parameters --- */
DEFINE INPUT  PARAMETER Pmode        AS CHARACTER               NO-UNDO.
DEFINE INPUT  PARAMETER Pcst-attr    AS CHARACTER               NO-UNDO.
DEFINE INPUT  PARAMETER Pnewtemplate AS CHARACTER               NO-UNDO.
DEFINE INPUT  PARAMETER Pshowoptions AS CHARACTER               NO-UNDO.
DEFINE OUTPUT PARAMETER Pfilechosen  AS CHARACTER               NO-UNDO.
DEFINE OUTPUT PARAMETER Potherthing  AS CHARACTER               NO-UNDO.
DEFINE OUTPUT PARAMETER Pcancelled   AS LOGICAL   INITIAL FALSE NO-UNDO.

/* --- Define local --- */
DEFINE VARIABLE Mgetfile    AS CHARACTER NO-UNDO.
DEFINE VARIABLE Mrtb-action AS CHARACTER NO-UNDO.
DEFINE VARIABLE MhTabletop  AS HANDLE    NO-UNDO.

/* --- MAIN BLOCK --- */

PUBLISH "evRtbGetDeskHandle":U (OUTPUT MhTabletop).
IF VALID-HANDLE(MhTabletop) THEN
DO:
    /* --- Publish intercept event --- */
    SESSION:SET-WAIT-STATE("").
    PUBLISH "evRtbAdeGetFile":U (INPUT  ?,
        INPUT  "UIB":U,
        INPUT  "Choose",
        INPUT  "",
        INPUT Pmode,
        INPUT-OUTPUT Pfilechosen,
        OUTPUT Mrtb-action).

    IF Mrtb-action = "Cancel" THEN
    DO:
        /* --- user cancelled selection of SmartObject --- */
        ASSIGN
            Pcancelled = YES.
        RETURN.
    END.  /* if mrtb-action = "cancel" */
    ELSE IF Mrtb-action = "Go" THEN
        DO:
            /* --- SmartObject selected from Roundtable --- */
            RETURN.
        END.  /* if mrtb-action = "go" */
END.

/* ---
   If we get this far, then we want to run PSC's "Choose SmartObject" dialog.
   Use the path to _adeload.r as the full path to _getfile.r.
   (It is supposed to be in the same adecomm directory, and Roundtable
   has no intercept for _adeload.r.)
   Don't use GET-KEY-VALUE to get DLC, just in case something weird has been
   done with the path to GUI/ADECOMM.
--- */

ASSIGN
    Mgetfile = SEARCH("adecomm/_adeload.r").

IF Mgetfile = ? THEN
DO:
    MESSAGE
        "Roundtable was unable to find adecomm/_adeload.r." SKIP
        "Please ensure that your propath to PROGRESS is set correctly."
        VIEW-AS ALERT-BOX ERROR.
    RETURN.
END.  /* if mgetfile = ? */

ASSIGN
    Mgetfile = REPLACE(Mgetfile,"_adeload","_chosobj").

IF SEARCH(Mgetfile) = ? THEN
DO:
    MESSAGE
        "Roundtable was unable to find adecomm/_getfile.r.  Ensure that your propath to PROGRESS is set correctly and try again."
        VIEW-AS ALERT-BOX ERROR
        TITLE "Roundtable Choose SmartObject".
    RETURN.
END.  /* if search(mgetfile) = ? */

/* --- run Progress _chosobj.p --- */
RUN VALUE(Mgetfile) (
    INPUT  Pmode,
    INPUT  Pcst-attr,
    INPUT  Pnewtemplate,
    INPUT  Pshowoptions,
    OUTPUT Pfilechosen,
    OUTPUT Potherthing,
    OUTPUT Pcancelled).
